@@ -1,7 +1,7 @@
 package Data::Section::Seekable::Reader;
 
-our $DATE = '2015-06-18'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-10-21'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -22,12 +22,20 @@ sub new {
 
 # BEGIN_BLOCK: read_dss_toc
 
-        my $header_line = <$fh>;
-        defined($header_line)
-            or die "Unexpected end of data section while reading header line";
-        chomp($header_line);
-        $header_line eq 'Data::Section::Seekable v1'
-            or die "Invalid header, must be 'Data::Section::Seekable v1' (got: $header_line)";
+        my $header_line;
+        my $header_found;
+        while (1) {
+            my $header_line = <$fh>;
+            defined($header_line)
+                or die "Unexpected end of data section while reading header line";
+            chomp($header_line);
+            if ($header_line eq 'Data::Section::Seekable v1') {
+                $header_found++;
+                last;
+            }
+        }
+        die "Can't find header 'Data::Section::Seekable v1'"
+            unless $header_found;
 
         my %toc;
         my $i = 0;
@@ -94,7 +102,7 @@ Data::Section::Seekable::Reader - Read parts from data section
 
 =head1 VERSION
 
-This document describes version 0.06 of Data::Section::Seekable::Reader (from Perl distribution Data-Section-Seekable), released on 2015-06-18.
+This document describes version 0.07 of Data::Section::Seekable::Reader (from Perl distribution Data-Section-Seekable), released on 2015-10-21.
 
 =head1 SYNOPSIS
 
